@@ -1,14 +1,16 @@
 /*
+ * $Id: main.cpp,v 1.31 2008/08/07 18:25:41 tyreld Exp $
+ *
  * main.cpp
  *
- * (C) Copyright IBM Corp. 2002, 2004
+ * (C) Copyright IBM Corp. 2002, 2004, 2008
  *
- * THIS FILE IS PROVIDED UNDER THE TERMS OF THE COMMON PUBLIC LICENSE
+ * THIS FILE IS PROVIDED UNDER THE TERMS OF THE ECLIPSE PUBLIC LICENSE
  * ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS FILE
  * CONSTITUTES RECIPIENTS ACCEPTANCE OF THE AGREEMENT.
  *
- * You can obtain a current copy of the Common Public License from
- * http://oss.software.ibm.com/developerworks/opensource/license-cpl.html
+ * You can obtain a current copy of the Eclipse Public License from
+ * http://www.opensource.org/licenses/eclipse-1.0.php
  *
  * Author:       Adrian Schuur <schuur@de.ibm.com>
  * Contributors: Viktor Mihajlovski <mihajlov@de.ibm.com>
@@ -17,6 +19,7 @@
  *               Heidi Neumann  <heidineu@de.ibm.com>
  *               David Eger <dteger@us.ibm.com>
  *               Philip K. Warren <pkw@us.ibm.com>
+ *               Tyrel Datwyler <tyreld@us.ibm.com>
  *
  * Description: Line command interface to DMTF conforming WBEM servers
 */
@@ -25,6 +28,10 @@
 #include "config.h"
 #endif
 
+#if HAVE_STRING_H
+#include <string.h>
+#endif
+
 #include "CimXml.h"
 
 #ifdef HAVE_LIBWWW
@@ -194,7 +201,7 @@ int main (int argc, char *argv[]) {
  	   else if (strcmp(*argv,"-ar")==0) role=*(++argv);
  	   else if (strcmp(*argv,"-arr")==0) resultRole=*(++argv);
            else if (strcmp(*argv,"-v")==0) {
-              cerr<<"* wbemcli Version " PACKAGE_VERSION ", $Date: 2005/11/21 12:33:19 $" <<endl;
+              cerr<<"* wbemcli Version " PACKAGE_VERSION ", $Date: 2008/08/07 18:25:41 $" <<endl;
            }
            else err=1;
          }
@@ -464,15 +471,13 @@ int main (int argc, char *argv[]) {
       case AssociatorNames:
          if (url.cName == "")
            throw CmdException("Class name not specified");
-         if (url.keys.size() == 0)
-           throw CmdException("Keys not specified");
 	 //	 if (BAD_ASSOC_NAMES_PARMS)
 	 //           throw CmdException("Invalid command invocation");
          if ((ina=cimom.associatorNames(url,assocClass,resultClass,role,resultRole))) {
             for (int i=0,s=ina->size(); i<s; i++) {
                sb.erase();
                InstanceNameXml& n=(*ina)[i];
-               url.toStringBuffer(sb,1);
+               // url.toStringBuffer(sb,1);
                n.toStringBuffer(sb,":");
                cout << sb << endl;
             }
@@ -482,16 +487,14 @@ int main (int argc, char *argv[]) {
       case Associators:
          if (url.cName == "")
            throw CmdException("Class name not specified");
-         if (url.keys.size() == 0)
-           throw CmdException("Keys not specified");
          if ((owp=cimom.associators(url,assocClass,resultClass,role,resultRole,xtraStr))) {
             for (int i=0,s=owp->size(); i<s; i++) {
                sb.erase();
                InstanceXml in=owp->getInst(i);
                InstancePathXml n=owp->getName(i);
-               url.toStringBuffer(sb,1);
+               // url.toStringBuffer(sb,1);
                n.toStringBuffer(sb,":");
-	       in.propagateKeyFlags(n.name.keys);
+	            in.propagateKeyFlags(n.name.keys);
                if (useNl) sb += "\n";
                else sb += " ";
                in.toStringBuffer(sb);
@@ -503,15 +506,13 @@ int main (int argc, char *argv[]) {
       case ReferenceNames:
          if (url.cName == "")
            throw CmdException("Class name not specified");
-         if (url.keys.size() == 0)
-           throw CmdException("Keys not specified");
 	 if (BAD_REFERENCES_PARMS)
            throw CmdException("Invalid command invocation");
          if ((ina=cimom.referenceNames(url,resultClass,role))) {
             for (int i=0,s=ina->size(); i<s; i++) {
                sb.erase();
                InstanceNameXml& n=(*ina)[i];
-               url.toStringBuffer(sb,1);
+               //url.toStringBuffer(sb,1);
                n.toStringBuffer(sb,":");
                cout << sb << endl;
             }
@@ -521,8 +522,6 @@ int main (int argc, char *argv[]) {
       case References:
          if (url.cName == "")
            throw CmdException("Class name not specified");
-         if (url.keys.size() == 0)
-           throw CmdException("Keys not specified");
 	 if (BAD_REFERENCES_PARMS)
            throw CmdException("Invalid command invocation");
          if ((owp=cimom.references(url,resultClass,role,xtraStr))) {
@@ -530,7 +529,7 @@ int main (int argc, char *argv[]) {
                sb.erase();
                InstanceXml in=owp->getInst(i);
                InstancePathXml n=owp->getName(i);
-               url.toStringBuffer(sb,1);
+               //url.toStringBuffer(sb,1);
                n.toStringBuffer(sb,":");
 	       in.propagateKeyFlags(n.name.keys);
                if (useNl) sb += "\n";
